@@ -4,7 +4,7 @@ import base32hex
 from .make_hashable import represent_and_encode
 
 
-def hash_object(obj, base=64):
+def hash_object(obj, n_jobs, base=64):
 	"""
 	:type obj: Obj
 	:type base: int
@@ -16,7 +16,7 @@ def hash_object(obj, base=64):
 		return obj.__hash32__()
 
 	hash_maker = hashlib.sha256()
-	hash_maker.update(represent_and_encode(obj))
+	hash_maker.update(represent_and_encode(obj, n_jobs=n_jobs))
 	if base == 64:
 		return base64.b64encode(hash_maker.digest()).decode()
 	elif base == 32:
