@@ -13,8 +13,8 @@ import base64
 from .to_bytes import to_bytes
 
 
-def hash_int(x):
-	s = represent_and_encode(x)
+def hash_int(x, n_jobs):
+	s = represent_and_encode(x, n_jobs=n_jobs)
 	_hash_maker = hashlib.sha256()
 
 	encoded = to_bytes(s)  # instead of x.encode()
@@ -44,13 +44,13 @@ def concat_spark_columns(data, name='concat_column', sep='|', return_data=False)
 		return data.select(name)
 
 
-def map_spark_to_int(data):
+def map_spark_to_int(data, n_jobs):
 	def _map_function(row):
 		"""
 		:type row: Row
 		:rtype: list[int]
 		"""
-		return [hash_int(x) for column, x in row.asDict().items()]
+		return [hash_int(x, n_jobs=n_jobs) for column, x in row.asDict().items()]
 
 	return data.rdd.map(_map_function).toDF(data.columns)
 
@@ -173,7 +173,7 @@ def make_dataframe_hashable(data, n_jobs):
 	# convert each value in the column into an int hash
 
 	if use == 'spark':
-		spark_int_data = map_spark_to_int(spark_compressed)
+		spark_int_data = map_spark_to_int(spark_compressed, n_jobs=n_jobs)
 		spark_aggregate = aggregate_spark_int(spark_int_data, n_jobs=n_jobs)
 		aggregate_dictionary = spark_aggregate.first().asDict()
 
